//
//  Test_3x3getRot.h
//  BulletTest
//
//  Copyright (c) 2011 Apple Inc.
//

#ifndef BulletTest_Test_3x3getRot_h
#define BulletTest_Test_3x3getRot_h

#ifdef __cplusplus
extern "C"
{
#endif

	int Test_3x3getRot(void);

#ifdef __cplusplus
}
#endif

#endif
